/*
 * Copyright (C) 2001-2004 Red Hat Inc. All Rights Reserved.
 *
 * The contents of this file are subject to the CCM Public
 * License (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the
 * License at http://www.redhat.com/licenses/ccmpl.html.
 *
 * Software distributed under the License is distributed on an
 * "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, either express
 * or implied. See the License for the specific language
 * governing rights and limitations under the License.
 *
 */
package com.arsdigita.bebop.parameters;

import javax.servlet.http.HttpServletRequest;

/**
 *    A class that represents the model for number form parameters.
 *
 *    @author Karl Goldstein 
 *    @author Uday Mathur 
 *    @version $Id: //core-platform/dev/src/com/arsdigita/bebop/parameters/NumberParameter.java#8 $
 */
public class NumberParameter extends ParameterModel {

    public static final String versionId = "$Id: //core-platform/dev/src/com/arsdigita/bebop/parameters/NumberParameter.java#8 $ by $Author: dennis $, $DateTime: 2004/04/07 16:07:11 $";

    public NumberParameter(String name) {
        super(name);
        try {
            this.addParameterListener
                (new TypeCheckValidationListener(Class.forName("java.lang.Number")));
        } catch (ClassNotFoundException cnfe) {
            throw new RuntimeException(cnfe.getMessage());
        }
    }

    public Object transformValue(HttpServletRequest request)
        throws IllegalArgumentException {
        return transformSingleValue(request);
    }

    public Object unmarshal(String encoded) {
        try {
            return new Integer(encoded);
        }
        catch (NumberFormatException e) {
            try {
                return new Float(encoded);
            } catch (NumberFormatException e2) {
                throw new IllegalArgumentException(getName()
                                                   + " should be a Number but is '" + encoded +"'");
            }
        }
    }

    public Class getValueClass() {
        return Number.class;
    }

}
